# @todo

class PluginManager(object):
    def __init__(self, app):
        self.app = app
        self.plugins = []

    def load_routes(self):
        pass

    def load_plugin(self, plugin):
        pass
